searchData={"items":[{"type":"module","title":"Yugo","doc":"Auxiliary functions for Yugo.","ref":"Yugo.html"},{"type":"type","title":"Yugo.address/0","doc":"The first field is the name associated with the address, and the second field is the address itself.\n\ne.g. `{\"Bart\", \"bart@simpsons.family\"}`","ref":"Yugo.html#t:address/0"},{"type":"type","title":"Yugo.body/0","doc":"A body can be either \"onepart\" or \"multipart\".\n\nA \"onepart\" body is a tuple in the form `{mime_type, params, content}`, where `mime_type` is a [`mime_type`](`t:mime_type/0`),\n`params` is a string->string map, and `content` is a [`binary`](`t:binary/0`).\n\nA \"multipart\" body consists of a *list* of [`body`s](`t:body/0`), which can themselves be either onepart or multipart.","ref":"Yugo.html#t:body/0"},{"type":"type","title":"Yugo.email/0","doc":"An email message sent to a subscribed process.\n\n# Difference between `sender` and `from`\nBoth \"sender\" and \"from\" are fields used by IMAP to indicate the origin of the email.\nThey are *usually* the same, but they can be different and they have different meanings:\n- `from` - the author who physically wrote the email. `From` is typically the address you see when viewing the message in an email client.\n- `sender` - the person who sent the email, potentially different than `from` if someone else sent the email on behalf of the author.","ref":"Yugo.html#t:email/0"},{"type":"type","title":"Yugo.flag/0","doc":"","ref":"Yugo.html#t:flag/0"},{"type":"type","title":"Yugo.mime_type/0","doc":"e.g. `\"text/html\"`, `\"image/png\"`, `\"text/plain\"`, etc.\n\nFor more, see this [list of MIME types](https://developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/MIME_types).","ref":"Yugo.html#t:mime_type/0"},{"type":"function","title":"Yugo.subscribe/2","doc":"Subscribes the calling process to the [`Client`](`Yugo.Client`) named by `client_name`.\n\nWhen you subscribe to a client, your process will be notified about new emails via a message\nin the form `{:email, client, message}`, where `client` is the name of the client that is notifying you,\nand `message` is the email. See the [`email`](`t:Yugo.email/0`) type for the structure of the `message` field.\n\nYou may also pass an optional [`Filter`](`Yugo.Filter`) as the second argument to match what\nemails you want to be notified about. If you do not pass a filter, it defaults to [`Filter.all`](`Yugo.Filter.all/0`),\nwhich allows all emails to pass through.","ref":"Yugo.html#subscribe/2"},{"type":"function","title":"Yugo.unsubscribe/1","doc":"Unsubscribes the calling process from the specified [`Client`](`Yugo.Client`).\n\nThis will unsubscribe the calling process from all messages from the client,\nregardless of how many separate times you [`subscribe`d](`subscribe/2`)","ref":"Yugo.html#unsubscribe/1"},{"type":"module","title":"Yugo.Client","doc":"A persistent connection to an IMAP server.\n\nNormally you do not call the functions in this module directly, but rather start a [`Client`](`Yugo.Client`) as part\nof your application's supervision tree. For example:\n\n    defmodule MyApp.Application do\n      use Application\n\n      @impl true\n      def start(_type, _args) do\n        children = [\n          {Yugo.Client,\n           name: :example_client,\n           server: \"imap.example.com\",\n           username: \"me@example.com\",\n           password: \"pa55w0rd\"}\n        ]\n\n        Supervisor.start_link(children, strategy: :one_for_one)\n      end\n    end\n\nSee [`start_link`](`Yugo.Client.start_link/1`) for a list of possible arguments.","ref":"Yugo.Client.html"},{"type":"function","title":"Yugo.Client.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Yugo.Client.html#child_spec/1"},{"type":"type","title":"Yugo.Client.name/0","doc":"The identifier used to refer to a [`Client`](`Yugo.Client`).","ref":"Yugo.Client.html#t:name/0"},{"type":"function","title":"Yugo.Client.start_link/1","doc":"Starts an IMAP client process linked to the calling process.\n\nTakes arguments as a keyword list.","ref":"Yugo.Client.html#start_link/1"},{"type":"function","title":"Arguments - Yugo.Client.start_link/1","doc":"* `:username` - Required. Username used to log in.\n\n  * `:password` - Required. Password used to log in.\n\n  * `:name` - Required. A name used to reference this [`Client`](`Yugo.Client`). Can be any term.\n\n  * `:server` - Required. The location of the IMAP server, e.g. `\"imap.example.com\"`.\n\n  * `:port` - The port to connect to the server via. Defaults to `993`.\n\n  * `:tls` - Whether or not to connect using TLS. Defaults to `true`. If you set this to `false`,\n  Yugo will make the initial connection without TLS, then upgrade to a TLS connection (using STARTTLS)\n  before logging in. Yugo will never send login credentials over an insecure connection.\n\n  * `:mailbox` - The name of the mailbox to monitor for emails. Defaults to `\"INBOX\"`.\n  The default \"INBOX\" mailbox is defined in the IMAP standard. If your account has other mailboxes,\n  you can pass the name of one as a string. A single [`Client`](`Yugo.Client`) can only monitor a single mailbox -\n  to monitor multiple mailboxes, you need to start multiple [`Client`](`Yugo.Client`)s.","ref":"Yugo.Client.html#start_link/1-arguments"},{"type":"function","title":"Advanced Arguments - Yugo.Client.start_link/1","doc":"The following options are provided because they can be useful, but in most cases you won't\n  need to change them from the default, unless you know what you're doing.\n\n  * `:ssl_verify` - The `:verify` option passed to `:ssl.connect/2`. Can be `:verify_peer` or `:verify_none`.\n  Defaults to `:verify_peer`.","ref":"Yugo.Client.html#start_link/1-advanced-arguments"},{"type":"function","title":"Example - Yugo.Client.start_link/1","doc":"Normally, you do not call this function directly, but rather run it as part of your application's supervision tree.\nSee the top of this page for example `Application` usage.","ref":"Yugo.Client.html#start_link/1-example"},{"type":"module","title":"Yugo.Filter","doc":"A construct that enables you to specify which emails you would\nlike a [`Client`](`Yugo.Client`) to notify you about.","ref":"Yugo.Filter.html"},{"type":"module","title":"Example - Yugo.Filter","doc":"To create a filter that only accepts emails that have been read and not replied to, and whose subject contains \"Order Information\":\n\n    alias Yugo.Filter\n\n    my_filter =\n      Filter.all()\n      |> Filter.has_flag(:seen)\n      |> Filter.lacks_flag(:answered)\n      |> Filter.subject_matches(~r/Order Information/)","ref":"Yugo.Filter.html#module-example"},{"type":"function","title":"Yugo.Filter.all/0","doc":"Returns a [`Filter`](`Yugo.Filter`) that accepts all emails.","ref":"Yugo.Filter.html#all/0"},{"type":"function","title":"Yugo.Filter.has_flag/2","doc":"Only accepts emails that have the specified flag.\n\n\"Flags\" are tags that are associated with an email message.","ref":"Yugo.Filter.html#has_flag/2"},{"type":"function","title":"Flags - Yugo.Filter.has_flag/2","doc":"IMAP defines several flags that can be set by clients. Possible flags are:\n\n  * `:seen` - Message has been read.\n\n  * `:answered` - Message has been answered.\n\n  * `:flagged` - Message is \"flagged\" for urgent/special attention.\n\n  * `:draft` - Message has not completed composition (marked as a draft).\n\n  * `:deleted` - Message is \"deleted\". In most email clients, this means it was moved to the trash folder.","ref":"Yugo.Filter.html#has_flag/2-flags"},{"type":"function","title":"Example - Yugo.Filter.has_flag/2","doc":"alias Filter\n\n    # build a filter that only allows messages that have been seen.\n    Filter.all()\n    |> Filter.has_flag(:seen)","ref":"Yugo.Filter.html#has_flag/2-example"},{"type":"function","title":"Yugo.Filter.lacks_flag/2","doc":"Only accepts emails that do not have the specified flag.\nSee `has_flag/2` for more information about flags.","ref":"Yugo.Filter.html#lacks_flag/2"},{"type":"function","title":"Example - Yugo.Filter.lacks_flag/2","doc":"alias Filter\n\n    # build a filter that allows all messages that do not have the :deleted flag\n    Filter.all()\n    |> Filter.lacks_flag(:deleted)","ref":"Yugo.Filter.html#lacks_flag/2-example"},{"type":"function","title":"Yugo.Filter.sender_matches/2","doc":"Accepts emails where the email address of the sender matches the given `Regex`.","ref":"Yugo.Filter.html#sender_matches/2"},{"type":"function","title":"Example - Yugo.Filter.sender_matches/2","doc":"alias Yugo.Filter\n\n    # make a filter that only accepts emails sent from \"peter@example.com\" or \"alex@example.com\"\n    Filter.all()\n    |> Filter.sender_matches(~r/^(peter|alex)@example.com$/i)","ref":"Yugo.Filter.html#sender_matches/2-example"},{"type":"function","title":"Yugo.Filter.subject_matches/2","doc":"Accepts emails whose \"subject\" line matches the given `Regex`.","ref":"Yugo.Filter.html#subject_matches/2"},{"type":"type","title":"Yugo.Filter.t/0","doc":"","ref":"Yugo.Filter.html#t:t/0"},{"type":"extras","title":"Yugo","doc":"# Yugo\n\nYugo is an easy and high-level IMAP client library for Elixir.\n\n\nTo begin, start a `Yugo.Client` as part of your application's supervision tree:\n```elixir\ndefmodule MyApp.Application do\n  use Application\n\n  @impl true\n  def start(_type, _args) do\n    children = [\n      {Yugo.Client,\n       name: :example_client,\n       server: \"imap.example.com\",\n       username: \"me@example.com\",\n       password: \"pa55w0rd\"}\n    ]\n\n    Supervisor.start_link(children, strategy: :one_for_one)\n  end\nend\n```\n\nNow you can call `Yugo.subscribe/2` to have your process receive messages whenever a new email arrives that matches the provided `Yugo.Filter`:\n\n```elixir\n# filter to only notify us about messages containing \"hello\" or \"goodbye\" in the subject:\nmy_filter =\n  Yugo.Filter.all()\n  |> Yugo.Filter.subject_matches(~r/(hello|goodbye)/)\n\n# By subscribing, our process will be notified about all future emails that match the filter.\nYugo.subscribe(:example_client, my_filter)\n\nreceive do\n  {:email, _client, message} ->\n    IO.puts(\"Received an email with subject `#{message.subject}`:\")\n    IO.inspect(message)\nend\n```","ref":"readme.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}